==> openweather-1.0.0.tar.gz: lib/src/api.dart <==
import 'dart:convert';
import 'package:http/http.dart' as http;
import 'package:openweather/src/models.dart';
import './global.dart';

class OpenWeatherClient {
  /// API Client for openweather
  String unit;
  String language;
  String apiKey;
  String apiURL;
  OpenWeatherClient(this.apiKey,
      {String language = 'en',
      String baseURL = BASE_URL,
      String version = VERSION,
      String unit}) {
    this.language = language;
    this.apiURL = "$baseURL/data/$version";
    this.unit = unit;
  }

  /// Helper function to build query parameter string from map data.
  String buildParams([Map<String, dynamic> params]) {
    Map<String, dynamic> allParams = params ?? {};
    allParams['lang'] = this.language;
    allParams['APPID'] = this.apiKey;
    if (this.unit != null) {
      allParams['unit'] = this.unit;
    }
    // print(allParams);

    List<String> paramStrings = [];
    allParams.forEach((key, val) => paramStrings.add("$key=${val.toString()}"));
    // print(paramStrings);
    if (paramStrings.isNotEmpty) {
      return "?${paramStrings.join('&')}";
    } else {
      return "";
    }
  }

  /// Helper function to build full URL from path and params.
  String buildURL(String path, [Map<String, dynamic> params]) =>
      "$apiURL$path${this.buildParams(params)}";

  /// Get map data from get request.
  Future<Map<String, dynamic>> mapFromGet(String path,
      [Map<String, dynamic> params]) async {
    var url = this.buildURL(path, params);
    try {
      var response = await http.get(url);
      // print(response.body);
      return jsonDecode(response.body);
    } catch (e) {
      rethrow;
    }
  }

  /// Get current weather data by City Name and optionally with country code.
  Future<CurrentWeather> getCurrentWeatherByCityName(String city,
      [String country]) async {
    Map<String, dynamic> params = {
      'q': (country == null) ? city : "$city,$country"
    };
    try {
      var data = await mapFromGet('/weather', params);
      return CurrentWeather.fromJSON(data);
    } catch (e) {
      rethrow;
    }
  }

  /// Get current weather data by City ID.
  Future<CurrentWeather> getCurrentWeatherByCityID(int cityID) async {
    Map<String, dynamic> params = {'id': cityID};
    try {
      var data = await mapFromGet('/weather', params);
      return CurrentWeather.fromJSON(data);
    } catch (e) {
      rethrow;
    }
  }

  /// Get current weather data by Coordinate.
  Future<CurrentWeather> getCurrentWeatherByCoordinate(
      {double lat, double lon}) async {
    Map<String, dynamic> params = {"lat": lat, "lon": lon};
    try {
      var data = await mapFromGet('/weather', params);
      return CurrentWeather.fromJSON(data);
    } catch (e) {
      rethrow;
    }
  }

  /// Get current weather data by ZIP code and optionally with country code.
  Future<CurrentWeather> getCurrentWeatherByZIPCode(int zip,
      [String country]) async {
    Map<String, dynamic> params = {
      'zip': (country == null) ? "$zip" : "$zip,$country"
    };
    try {
      var data = await mapFromGet('/weather', params);
      return CurrentWeather.fromJSON(data);
    } catch (e) {
      rethrow;
    }
  }
}

==> openweather-1.9.0.tar.gz: lib/src/api.dart <==
import 'dart:convert';
import 'package:http/http.dart' as http;
import 'package:openweather/src/models.dart';
import './global.dart';

class OpenWeatherClient {
  /// API Client for openweather
  String unit;
  String language;
  String apiKey;
  String apiURL;
  OpenWeatherClient(this.apiKey,
      {String language = 'en',
      String baseURL = BASE_URL,
      String version = VERSION,
      String unit}) {
    this.language = language;
    this.apiURL = "$baseURL/data/$version";
    this.unit = unit;
  }

  /// Helper function to build query parameter string from map data.
  String buildParams([Map<String, dynamic> params]) {
    Map<String, dynamic> allParams = params ?? {};
    allParams['lang'] = this.language;
    allParams['APPID'] = this.apiKey;
    if (this.unit != null) {
      allParams['unit'] = this.unit;
    }
    // print(allParams);

    List<String> paramStrings = [];
    allParams.forEach((key, val) => paramStrings.add("$key=${val.toString()}"));
    // print(paramStrings);
    if (paramStrings.isNotEmpty) {
      return "?${paramStrings.join('&')}";
    } else {
      return "";
    }
  }

  /// Helper function to build full URL from path and params.
  String buildURL(String path, [Map<String, dynamic> params]) =>
      "$apiURL$path${this.buildParams(params)}";

  /// Get map data from get request.
  Future<Map<String, dynamic>> mapFromGet(String path,
      [Map<String, dynamic> params]) async {
    var url = this.buildURL(path, params);
    try {
      var response = await http.get(url);
      // print(response.body);
      return jsonDecode(response.body);
    } catch (e) {
      rethrow;
    }
  }

  /// Get current weather data by City Name and optionally with country code.
  Future<CityWeather> getCityWeatherByCityName(String city,
      [String country]) async {
    Map<String, dynamic> params = {
      'q': (country == null) ? city : "$city,$country"
    };
    try {
      var data = await mapFromGet('/weather', params);
      return CityWeather.fromJSON(data);
    } catch (e) {
      rethrow;
    }
  }

  /// Get current weather data by City ID.
  Future<CityWeather> getCityWeatherByCityID(int cityID) async {
    Map<String, dynamic> params = {'id': cityID};
    try {
      var data = await mapFromGet('/weather', params);
      return CityWeather.fromJSON(data);
    } catch (e) {
      rethrow;
    }
  }

  /// Get current weather data by Coordinate.
  Future<CityWeather> getCityWeatherByCoordinate(
      {double lat, double lon}) async {
    Map<String, dynamic> params = {"lat": lat, "lon": lon};
    try {
      var data = await mapFromGet('/weather', params);
      return CityWeather.fromJSON(data);
    } catch (e) {
      rethrow;
    }
  }

  /// Get current weather data by ZIP code and optionally with country code.
  Future<CityWeather> getCityWeatherByZIPCode(int zip, [String country]) async {
    Map<String, dynamic> params = {
      'zip': (country == null) ? "$zip" : "$zip,$country"
    };
    try {
      var data = await mapFromGet('/weather', params);
      return CityWeather.fromJSON(data);
    } catch (e) {
      rethrow;
    }
  }

  Future<RectLocResponse> getCityWeatherByRectangle(double lonLeft,
      double latBottom, double lonRight, double latTop, int zoom) async {
    Map<String, dynamic> params = {
      'bbox': "$lonLeft,$latBottom,$lonRight,$latTop,$zoom"
    };
    try {
      var data = await mapFromGet('/box/city', params);
      return new RectLocResponse.fromJSON(data);
    } catch (e) {
      rethrow;
    }
  }

  Future<CitiesInCycleResponse> getCitiesWeatherInCycle(double lat, double lon,
      [int cnt = 10]) async {
    Map<String, dynamic> params = {'lat': lat, 'lon': lon, 'cnt': cnt};
    try {
      var data = await mapFromGet('/find', params);
      return new CitiesInCycleResponse.fromJSON(data);
    } catch (e) {
      rethrow;
    }
  }

  Future<CitiesByIDResponse> getCitiesWeatherbyID(List<int> citiesID) async {
    Map<String, dynamic> params = {'id': citiesID.join(",")};
    try {
      var data = await mapFromGet('/group', params);
      return new CitiesByIDResponse.fromJSON(data);
    } catch (e) {
      rethrow;
    }
  }
}
